Documentation
¶
Index ¶
- func Configure(ctx *pulumi.Context, repositories []*repoConf.Config, ...) (map[string][]string, error)
- func ConfigureWorkloadIdentityPools(ctx *pulumi.Context, ...) (map[string]*google.WorkloadIdentityPool, error)
- func EnableProjectServices(ctx *pulumi.Context, ...) (map[string][]pulumi.Resource, error)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Configure ¶
func Configure(ctx *pulumi.Context, repositories []*repoConf.Config, vaultStores map[string]*vault.Mount, gcpConfig *googleConf.Config, repositoriesConfig *repositories.Config, ) (map[string][]string, error)
Configure sets up Google Cloud resources based on the provided configuration. ctx: Pulumi context for resource management. repositories: List of repository configurations. vaultStores: Map of Vault mount configurations. gcpConfig: Google Cloud configuration details. repositoriesConfig: Repository configuration details.
func ConfigureWorkloadIdentityPools ¶
func ConfigureWorkloadIdentityPools(ctx *pulumi.Context, googleRepositoryProjects map[string]*google.RepositoryProject, providers map[string]*gcp.Provider, enabledServices map[string][]pulumi.Resource, ) (map[string]*google.WorkloadIdentityPool, error)
ConfigureWorkloadIdentityPools sets up Workload Identity Pools for the given Google Cloud projects. ctx: Pulumi context for resource management. googleRepositoryProjects: Map of repository projects with their configurations. providers: Map of GCP providers configured for specific projects. enabledServices: Map of enabled services for each project.
func EnableProjectServices ¶
func EnableProjectServices(ctx *pulumi.Context, googleRepositoryProjects map[string]*google.RepositoryProject, gcpConfig *googleConf.Config, providers map[string]*gcp.Provider, ) (map[string][]pulumi.Resource, error)
EnableProjectServices enables the specified services for the given Google Cloud projects. ctx: Pulumi context for resource management. googleRepositoryProjects: Map of repository projects with their configurations. gcpConfig: Google Cloud configuration details. providers: Map of GCP providers configured for specific projects.
Types ¶
This section is empty.